function SMH=calibrateSMH(C, N , gCFgIF, gIR, H0, tstart)
%
% This calibrates the hidden SMH model from a given C data vector
% in a population of size N
% from an index tstart on, where C(tstart) must be defined 
% H0 will then be H(tstart).
% This runs to the end of C, whatever it is. 
% No smoothing of C.
%
% Input:
% 
% C = Confirmed, cumulative,
%     like in Johns Hopkins data
%
% Parameters:
%
% gIR is gamma_{IR} in the paper 
% gCFgIF is gamma_{CF}/gamma_{IF} in the paper
%
% Output: 
% 
% S = Susceptibles, 
% M = unregistered Infectious
% H = unregistered Recovered
% 
% S, M, H as full vectors of the same length as C.
% SMH is [S M H] as a matrix of 3 columns.
% S will be fully calculated.
% M, H will have zeros up to tstart, where the
% calculation begins. 
% The starting value for M is
% calculated from N=S+M+H+C at tstart, using H0.
%
len=length(C);
% get vectors as columns, full size
S=zeros(len,1);
H=zeros(len,1);
M=zeros(len,1);
% We need S(tstart) later, therefore S is calculated beforehand
S(1)=N; % canonical starting value for S 
% Get the full S values, like in paper
for i=2:len
    S(i,1)=S(i-1,1)-(gCFgIF)*(C(i)-C(i-1));
end
% prepare startup for H and M
H(tstart,1)=H0;
M(tstart,1)=N-S(tstart)-H0-C(tstart);
% then run the SMH model like in the paper
for i=tstart+1:len
    M(i,1)=M(i-1,1)*(1-gIR)+(gCFgIF -1)*(C(i)-C(i-1));
    H(i,1)=H(i-1,1)+gIR*M(i-1,1);
end
% assemble into one matrix
SMH=[S M H];
